# Clay Changelog


## Version 1.0.24

- Fix bug with custom settings being overwritten by the default ones.
- Fix a bug with the markdown plugin while searching automatically for the first header.


## Version 1.0.23

- Clay now runs on Windows.
- Removed typographer extension.
